//	Bee.cpp - The bee class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Random.h"
#include "Flower.h"
#include "Bee.h"

//------------------------------------------------------------------------------
Bee::Bee(const TwoFloats& pos):
position(pos),
switchDir(0.0f)
{
	int i;
	float tempf;

	dirIndex = Random::getGlobal().getRandomFloat();

	for(i=0;i<TrailSize;++i)
	{
		tempf = (1.0f-((float)i/(float)(TrailSize-1)));

		trail.push_back(position);
		tempTrail.push_back(position);
		trailSize.push_back(fakeLog(tempf) * 12.0f);
		trailCol.push_back(1.0f);
		trailAlpha.push_back(tempf);
	}
}

//------------------------------------------------------------------------------
Bee::~Bee()
{

}

//------------------------------------------------------------------------------
void Bee::update(float delta, GamePlayState& state)
{
	int i;
	float angle;
	TwoFloats dir;
	const TwoFloats origin;

	if(switchDir <= 0.0f)
		selectDestination(state.getFlowers());
	else if(position.getDistance(destination) < 4.0f)
	{
		lastFlower = destination;
		selectDestination(state.getFlowers());
	}
	else
	{
		position += direction * 2.0f * delta;

		if(desiredDir.getDistance(direction) < 0.02f)
			direction = desiredDir;
		else
		{
			direction += (desiredDir-direction) * 0.01f;
			direction = direction.normal();
		}

		/*angle = origin.getAngle(desiredDir);
		angle += sinf(dirIndex * 2.0f * NIALL_PI) * 0.5f;
		direction.x = cosf(angle);
		direction.y = sinf(angle);

		dirIndex += 0.02f * delta;
		if(dirIndex > 1.0f)
			dirIndex = 0.0f;*/
	}

	for(i=(TrailSize-1);i>0;--i)
		trail[i] = trail[i-1];
	trail[0] = position;

	switchDir -= delta;
}

//------------------------------------------------------------------------------
void Bee::draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft)
{
	int i;

	if((position > (topLeft-12.0f)) &&
	   (position < (topLeft+d->getDrawingAreaSize()+12.0f)))
	{
		for(i=0;i<(int)trail.size();++i)
			tempTrail[i] = trail[i] - topLeft;
		d->drawConnectedLine(L"PlayerTrail",
							 tempTrail,
							 trailSize,
							 trailCol,
							 trailAlpha);

		d->drawImage(L"Blob",
					 position-topLeft-12.0f,
					 0.75f);
	}
}

//------------------------------------------------------------------------------
void Bee::selectDestination(const std::vector<shared_ptr<Flower> >& flowers)
{
	float dist;
	int i, j, k;
	float angle;
	TwoFloats dir;
	TwoFloats flowerPos;
	const TwoFloats origin;
	TwoFloats nearest[4] = {TwoFloats(100000.0f),
							TwoFloats(100000.0f),
							TwoFloats(100000.0f),
							TwoFloats(100000.0f)};
	float nearestDists[4] = {100000.0f, 100000.0f, 100000.0f, 100000.0f};

	for(i=0;i<(int)flowers.size();++i)
	{
		flowerPos = flowers[i]->getPosition();
		dist = position.getDistance(flowerPos);
		if((dist < nearestDists[3]) && (flowerPos != lastFlower))
		{
			for(j=0;j<4;++j)
			{
				if(dist < nearestDists[j])
				{
					for(k=3;k>j;--k)
					{
						nearest[k] = nearest[k-1];
						nearestDists[k] = nearestDists[k-1];
					}
					nearest[j] = flowerPos;
					nearestDists[j] = dist;
					break;
				}
			}
		}
	}

	i = Random::getGlobal().getRandomInt(4);
	destination = nearest[i];

	dir = (destination-position).normal();
	/*angle = origin.getAngle(dir);
	angle += (Random::getGlobal().getRandomFloat() * 0.4f)-0.2f;
	desiredDir.x = cosf(angle);
	desiredDir.y = sinf(angle);*/
	desiredDir = dir;

	switchDir = 240.0f;
}
