//	Bee.h - The bee class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BEE_H_
#define BEE_H_

#include "GamePlayState.h"
#include "c0xHeaders.h"
#include "TwoFloats.h"

#include <vector>

class Drawer;
class Flower;

///	The bee class.
class Bee
{
  public:
	///	Constructor.
	Bee(const TwoFloats& pos);
	///	Destructor.
	~Bee();

	///	Moves the bee.
	void update(float delta, GamePlayState& state);
	///	Draws the bee.
	void draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft);

	///	Returns the bee's position.
	const TwoFloats& getPosition() const {return position;};
	///	Returns the bee's radius.
	float getRadius() const {return 12.0f;};
  private:
	///	Helper method. Selects a random nearby flower.
	void selectDestination(const std::vector<shared_ptr<Flower> >& flowers);

	///	Used to draw the bee's tail.
	enum
	{
		TrailSize = 16
	};

	///	The bee's current position.
	TwoFloats position;
	///	The bee's direction.
	TwoFloats direction;
	///	The bee's current destination.
	TwoFloats destination;
	///	The bee's desired direction.
	TwoFloats desiredDir;

	///	Used to vary the bee's direction.
	float dirIndex;
	///	Used to vary the bee's direction.
	float switchDir;

	///	The position of the last flower the bee visited.
	TwoFloats lastFlower;

	///	Used to draw the player's trail.
	std::vector<TwoFloats> trail;
	///	Used to draw the player's trail.
	std::vector<TwoFloats> tempTrail;
	///	Used to draw the player's trail.
	std::vector<float> trailSize;
	///	Used to draw the player's trail.
	std::vector<ThreeFloats> trailCol;
	///	Used to draw the player's trail.
	std::vector<float> trailAlpha;
};

#endif
