//	Flower.h - The basic flower class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FLOWER_H_
#define FLOWER_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"

class GamePlayState;
class Drawer;

///	The basic flower class.
class Flower
{
  public:
	///	Constructor.
	Flower(const TwoFloats& pos, bool brandNew = false);
	///	Destructor.
	~Flower();

	///	Updates the flower.
	/*!
		\return True if the flower should be deleted.
	 */
	bool update(float delta);
	///	Draws the flower.
	void draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft);

	///	Called when something collides with this flower.
	/*!
		\return True if the flower generates a ring in response.
	 */
	bool collide(GamePlayState& state);

	///	Returns the flower's position.
	const TwoFloats& getPosition() const {return position;};
	///	Returns the flower's radius.
	float getRadius() const;
	///	Returns the flower's synth index.
	int getSynthIndex() const {return synthIndex;};
	///	Returns the flower's colour.
	const ThreeFloats& getColour() const {return colour;};
  private:
	///	The flower's position.
	TwoFloats position;
	///	The flower's life.
	float life;
	///	The flower's synth index.
	int synthIndex;
	///	The flower's colour.
	ThreeFloats colour;

	///	Used to prevent the flower triggering rings in too close succession.
	float ringCount;

	///	Used to determine when to emit a seed after the flower's been pollinated.
	float seedCount;
};

#endif
