//	FlowerRing.cpp - The basic flower class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "FlowerRing.h"

//------------------------------------------------------------------------------
FlowerRing::FlowerRing(const TwoFloats& pos, const ThreeFloats& col):
position(pos),
radius(0.0f),
colour(col)
{

}

//------------------------------------------------------------------------------
FlowerRing::~FlowerRing()
{

}

//------------------------------------------------------------------------------
bool FlowerRing::update(float delta)
{
	bool retval = false;

	radius += delta * 4.0f;
	if(radius > 251.0f)
		retval = true;

	return retval;
}

//------------------------------------------------------------------------------
void FlowerRing::draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft)
{
	const float scale = radius/251.0f;

	if(position.isWithin(topLeft-radius, d->getDrawingAreaSize()+(radius*2.0f)))
	{
		d->drawImage(L"FlowerRing",
					 position-topLeft-radius,
					 scale,
					 colour,
					 fakeLog(1.0f-scale));
	}
}
