//	FlowerRing.h - The basic flower class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FLOWERRING_H_
#define FLOWERRING_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"

class Drawer;

///	The basic flower class.
class FlowerRing
{
  public:
	///	Constructor.
	FlowerRing(const TwoFloats& pos, const ThreeFloats& col = ThreeFloats(1.0f));
	///	Destructor.
	~FlowerRing();

	///	Updates the ring.
	/*!
		\return True if the ring should be deleted.
	 */
	bool update(float delta);
	///	Draws the ring.
	void draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft);

	///	Returns the ring's position.
	const TwoFloats& getPosition() const {return position;};
	///	Returns the ring's radius.
	float getRadius() const {return radius;};
  private:
	///	The ring's position.
	TwoFloats position;
	///	The ring's current radius.
	float radius;
	///	The ring's colour.
	ThreeFloats colour;
};

#endif
