//	PastarenaSounder.h - The game's sounder.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PASTARENASOUNDER_H_
#define PASTARENASOUNDER_H_

#include "synth/PolyphonicSynth.h"
#include "synth/SimpleSynth.h"
#include "sound/Sounder.h"
#include "sound/Delay.h"

///	The game's sounder.
class PastarenaSounder : public Sounder
{
  public:
	///	Constructor.
	PastarenaSounder();
	///	Destructor.
	~PastarenaSounder();

	///	Called for every audio block.
	void getAudio(float *input, float *output, int numSamples);

	///	Called for each sound file resource by LoadingScreen.
	void loadSoundFileResource(SoundFileLoaderPtr soundFileLoader) {};

	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerHi(float val, int pitchSet);
	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerLo(int val, int pitchSet, float distance, float pan);
	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerSlow(float val, int pitchSet);
	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerMine(float val, int pitchSet);
	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerPickup(float val, int pitchSet);
	///	Triggers a synth note.
	/*!
		\param val A value 0->1 which will be mapped to a particular pitch.
	 */
	void triggerPew(float val, int pitchSet);

	///	Loads a random set of pitches to use.
	void loadPitches();
	///	Returns the number of pitch sets we have available.
	int getNumPitchSets() const {return pitches[0].size();};
  private:
	///	Some constants.
	enum
	{
		BufferSize = 16384
	};

	///	The hi synth.
	PolyphonicSynth<SimpleSynth> hiSynth;
	///	The hi synth delay.
	Delay hiDelay;

	///	The lo synth.
	PolyphonicSynth<SimpleSynth> loSynth;
	///	The lo synth delay.
	Delay loDelay;
	///	Temporary buffer for the lo synth.
	float loBuffer[BufferSize];

	///	The slow synth
	PolyphonicSynth<SimpleSynth> slowSynth;
	///	The slow synth delay.
	Delay slowDelay;
	///	Temporary buffer for the slow synth.
	float slowBuffer[BufferSize];

	///	The mine synth
	PolyphonicSynth<SimpleSynth> mineSynth;
	///	The slow mine delay.
	Delay mineDelay;
	///	Temporary buffer for the mine synth.
	float mineBuffer[BufferSize];

	///	The pickup synth
	PolyphonicSynth<SimpleSynth> pickupSynth;
	///	The slow mine delay.
	Delay pickupDelay;
	///	Temporary buffer for the mine synth.
	float pickupBuffer[BufferSize];

	///	The pew synth
	PolyphonicSynth<SimpleSynth> pewSynth;
	///	The pew delay.
	Delay pewDelay;
	///	Temporary buffer for the pew synth.
	float pewBuffer[BufferSize];

	///	The current pitch set.
	std::vector<float> pitches[8];
};

#endif
