//	Player.cpp - The player class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "GamePlayState.h"
#include "MiscHelper.h"
#include "Player.h"

//------------------------------------------------------------------------------
Player::Player():
position(640.0f*20.0f),
destination(position),
direction(0.0f, -1.0f),
bulletCount(15.0f)
{
	int i;
	float tempf;

	for(i=0;i<TrailSize;++i)
	{
		tempf = (1.0f-((float)i/(float)(TrailSize-1)));

		trail.push_back(position);
		tempTrail.push_back(position);
		trailSize.push_back(fakeLog(tempf) * 28.0f);
		trailCol.push_back(1.0f);
		trailAlpha.push_back(tempf);
	}
}

//------------------------------------------------------------------------------
Player::~Player()
{

}

//------------------------------------------------------------------------------
void Player::update(float delta, GamePlayState& state)
{
	int i;

	if(position != destination)
	{
		if(delta > 20.0f)
			delta = 20.0f;

		direction = (destination-position).normal();
		position += (destination-position) * 0.05f * delta;
		if(position.getDistance(destination) < 1.5f)
			position = destination;

		bulletCount -= delta;
		if(bulletCount <= 0.0f)
		{
			state.addPlayerBullet(position, direction);
			bulletCount = 15.0f;
		}
	}

	for(i=(TrailSize-1);i>0;--i)
		trail[i] = trail[i-1];
	trail[0] = position;
}

//------------------------------------------------------------------------------
void Player::draw(shared_ptr<Drawer>& d)
{
	int i;
	//float tempf;
	const TwoFloats topLeft(position - (d->getDrawingAreaSize()*0.5f));

	/*for(i=(TrailSize-1);i>=0;--i)
	{
		if(trail[i] == position)
			break;
		else
		{
			tempf = 1.0f - ((float)i/(float)TrailSize);
			d->drawImage(L"PlayerBlur",
						 trail[i]-topLeft-32.0f,
						 fakeLog(tempf),
						 1.0f,
						 tempf*0.5f);
		}
	}*/
	for(i=0;i<(int)trail.size();++i)
		tempTrail[i] = trail[i] - topLeft;
	d->drawConnectedLine(L"PlayerTrail",
						 tempTrail,
						 trailSize,
						 trailCol,
						 trailAlpha);
	d->drawImage(L"Player", position-topLeft-27.5f);
}

//------------------------------------------------------------------------------
void Player::move(const TwoFloats& val)
{
	destination += val;

	if(destination.x < 0.0f)
		destination.x = 0.0f;
	else if(destination.x >= (1280.0f*20.0f))
		destination.x = (1280.0f*20.0f);

	if(destination.y < 0.0f)
		destination.y = 0.0f;
	else if(destination.y >= (1280.0f*20.0f))
		destination.y = (1280.0f*20.0f);
}
