//	Player.h - The player class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "ThreeFloats.h"
#include "c0xHeaders.h"
#include "TwoFloats.h"

#include <vector>

class GamePlayState;
class Drawer;

///	The player class.
class Player
{
  public:
	///	Constructor.
	Player();
	///	Destructor.
	~Player();

	///	Moves the player.
	void update(float delta, GamePlayState& state);
	///	Draws the player.
	void draw(shared_ptr<Drawer>& d);

	///	Tells the player to move this number of pixels.
	void move(const TwoFloats& val);

	///	Returns the player's current position.
	const TwoFloats& getPosition() const {return position;};
  private:
	///	The number of images used to draw the player's trail.
	enum
	{
		TrailSize = 24
	};

	///	The player's current position.
	TwoFloats position;
	///	The player's desired position.
	TwoFloats destination;
	///	The player's current direction.
	TwoFloats direction;

	///	Used to draw the player's trail.
	std::vector<TwoFloats> trail;
	///	Used to draw the player's trail.
	std::vector<TwoFloats> tempTrail;
	///	Used to draw the player's trail.
	std::vector<float> trailSize;
	///	Used to draw the player's trail.
	std::vector<ThreeFloats> trailCol;
	///	Used to draw the player's trail.
	std::vector<float> trailAlpha;

	///	Used to determine when to fire a bullet.
	float bulletCount;
};

#endif
