//	Seed.cpp - The flower seed class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Random.h"
#include "Seed.h"

//------------------------------------------------------------------------------
Seed::Seed(const TwoFloats& pos):
position(pos)
{
	direction.x = (Random::getGlobal().getRandomFloat() * 2.0f) - 1.0f;
	direction.y = (Random::getGlobal().getRandomFloat() * 2.0f) - 1.0f;
	direction = direction.normal();

	life = 60.0f + (Random::getGlobal().getRandomFloat() * 60.0f);
}

//------------------------------------------------------------------------------
Seed::~Seed()
{

}

//------------------------------------------------------------------------------
bool Seed::update(float delta)
{
	bool retval = false;

	position += direction * 12.0f * delta;
	life -= delta;
	if(life <= 0.0f)
		retval = true;

	return retval;
}

//------------------------------------------------------------------------------
void Seed::draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft)
{
	const TwoFloats origin;
	const float angle = -origin.getAngle(direction);

	d->drawRotImage(L"PlayerBullet",
					position-topLeft-16.0f,
					angle,
					32.0f,
					1.0f,
					1.0f,
					fakeLog(life/120.0f));
}
