//	Seed.h - The flower seed class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SEED_H_
#define SEED_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"

class Drawer;

///	The player seed class.
class Seed
{
  public:
	///	Constructor.
	Seed(const TwoFloats& pos);
	///	Destructor.
	~Seed();

	///	Moves the seed.
	/*!
		\return True if the seed should be deleted and a flower should be
		created.
	 */
	bool update(float delta);
	///	Draws the seed.
	void draw(shared_ptr<Drawer>& d, const TwoFloats& topLeft);

	///	Returns the seed's position.
	const TwoFloats& getPosition() const {return position;};
	///	Returns the seed's direction.
	const TwoFloats& getDirection() const {return direction;};
	///	Returns the seed's radius.
	float getRadius() const {return 16.0f;};
  private:
	///	The seed's current position.
	TwoFloats position;
	///	The seed's direction.
	TwoFloats direction;
	///	The seed's life.
	float life;
};

#endif
